# Python demos

Simplified DP-class Domany-Kinzel model simulations are demonstrated in the Python scripts below.

![2d DP $t$-decay of mean order parameter $\overline\rho(t)$, for $p_c \approx p=0.163145$, $n_x=30000$, $n_y=30000$, $t=50000$](../images/ρmean_p0p163145_s1_nx30000_ny30000.png){width=500}

Quick tests to check all is working:

- [dp_test_1d.py](https://github.com/cstarkjp/DPRS/tree/main/demos/dp_test_1d.py)

- [dp_test_2d.py](https://github.com/cstarkjp/DPRS/tree/main/demos/dp_test_2d.py)

- [dp_test_3d.py](https://github.com/cstarkjp/DPRS/tree/main/demos/dp_test_3d.py)

More substantial simulations:

- [dp_fullcheck_1d.py](https://github.com/cstarkjp/DPRS/tree/main/demos/dp_fullcheck_1d.py)

- [dp_fullcheck_2d.py](https://github.com/cstarkjp/DPRS/tree/main/demos/dp_fullcheck_2d.py)

- [dp_fullcheck_3d.py](https://github.com/cstarkjp/DPRS/tree/main/demos/dp_fullcheck_3d.py)
